@@ -278,16 +278,16 @@ class PSquared(object):
         :param bool xml: True if the raw XML exchanges should be logged.
         :param str cert: path to the file containing the client\'s x509
             certificate, (default
-            ``${HOME}/.psquared/client/cert/psquare_client.pem``).
+            ``${HOME}/.psquared/client/cert/psquared_client.pem``).
         :param str key: path to the file containing path to the client\'s
             private x509 key (default
-            ``${HOME}/.psquared/client/private/psquare_client.key``).
+            ``${HOME}/.psquared/client/private/psquared_client.key``).
         :param str cacert: path to the file containing one or more CA x509
             certificates, (default
             ``${HOME}/.psquared/client/cert/cacert.pem``).
 
         The ``cert`` and ``key`` will only be used if the files
-        containing then exist, otherwise they are ignored.
+        containing them exist, otherwise they are ignored.
 
         The alternate ``cacert`` location is only used if the specified
         directory exists.
@@ -298,9 +298,9 @@ class PSquared(object):
         self.session=requests.Session()
         client_dir=os.getenv('HOME') + '/.psquared/client'
         if None == cert:
-            cert = client_dir + '/cert/psquare_client.pem' #Client certificate
+            cert = client_dir + '/cert/psquared_client.pem' #Client certificate
         if None == key:
-            key = client_dir + '/private/psquare_client.key' #Client private key
+            key = client_dir + '/private/psquared_client.key' #Client private key
         if None == cacert:
             cacert = client_dir + '/cert/cacert.pem' #CA certificate file
         if os.path.exists(cert) and os.path.exists(key):
